
create table five (five_col int);

comment on table five is '5 ± 1 = 4 or 6';
comment on column five.five_col is 'this is a column for fives';

